from rtools.package import *
import unittest

#@unittest.skip
def test_install_package():
    #install_packages("truncnorm")
    install_packages("truncnorm", repos=RPackageManager.cran_repos)


#@unittest.skip
def test_biocLite():
    biocLite("truncnorm")

def test_Rpackage():

    r = RPackage("base")
    r.version


    # load a non-existing package 
    # if does not exist, no error returned on purpose. only logging. so that one can try to import optional packages zitout errors if one is missing.
    r = RPackage("based")
    assert r.package == None

    # load a package that has not the required version
    # again, if does not exist, no error returned on purpose. only logging. so that one can try to import optional packages zitout errors if one is missing.
    r = RPackage("base", require="10000.0")
    assert r.package == None


def test_RPM():
    r = RPackageManager()
    r.install_packages("base")
    assert r.require("base", "1.0") == True
